@@ -79,20 +79,11 @@ compute_mallows <- function(
   validate_class(initial_values, "BayesMallowsInitialValues")
   validate_rankings(data)
   validate_preferences(data, model_options)
+  validate_rankings(data)
   validate_initial_values(initial_values, data)
 
-  pfun_values <- tryCatch(
-    prepare_partition_function(model_options$metric, data$n_items),
-    error = function(e) {
-      if (is.null(pfun_estimate)) {
-        stop(
-          "Exact partition function not known. Please provide an ",
-          "estimate in argument pfun_estimate."
-        )
-      } else {
-        return(NULL)
-      }
-    }
+  pfun_values <- extract_pfun_values(
+    model_options$metric, data$n_items, pfun_estimate
   )
 
   if (is.null(cl)) {
